-- liquibase formatted sql
-- changeset mbl@nine.dk:add-test_results-table

create or replace table test_results
(
    test_identifier            varchar(15) primary key not null comment 'Unik identifier af prøvesvaret',
    person_identifier          char(10)                not null comment 'CPR-nummer',
    type_of_test               varchar(15)             not null comment 'Description of the type of test that was conducted, e.g. RT-PCR or rapid antigen test.
In the case of a rapid antigen tests, the form should provide details on the manufacturer and commercial name of the test used',
    test_name                  varchar(50)             not null comment 'Commercial or brand name of the RT-PCR or rapid antigen test. Pt. kun for AG-test',
    test_manufacturer          varchar(50)             not null comment 'Manufacturer of the RT-PCR or rapid antigen test. Kun for AG-test',
    timestamp_sample           timestamp               not null comment 'Date when the sample for the test was collected',
    timestamp_result           timestamp               not null comment 'Date when the test was determined',
    result_of_the_test         boolean                 not null comment 'Negative (false) or positive (true)',
    testing_centre_or_facility varchar(50)             not null comment 'Name/code of testing centre, facility or a health authority responsible for the testing event. Kun for AG-test',
    timestamp_last_update      timestamp               not null comment 'Date when the test was last updated (in KIDS)',
    sletteflag                 bit                     not null comment 'Markering af logisk sletning, digi2: 0 for ikke-slettet og 1 for slettet'
);

create or replace unique index cpr_number on test_results (person_identifier);
